# Generated by Django 2.0.5 on 2018-05-20 05:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('cosmicdb', '0002_cosmicdbtreeitem_is_button'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='usersystemmessage',
            name='user',
        ),
        migrations.RemoveField(
            model_name='usersystemnotification',
            name='icon_class',
        ),
        migrations.DeleteModel(
            name='UserSystemMessage',
        ),
    ]



from django import forms
from django.contrib.auth.forms import AuthenticationForm, PasswordResetForm, SetPasswordForm, PasswordChangeForm
from django.contrib.auth import password_validation
from django.utils.html import format_html

from crispy_forms.helper import FormHelper
from crispy_forms.layout import Submit

from cosmicdb.models import User


class CosmicFormHelper(FormHelper):
    def __init__(self, form=None, save_button=True, save_button_value='Save', save_button_name='save', save_button_extra_css=''):
        super().__init__(form)
        if save_button:
            self.add_input(Submit(save_button_name, save_button_value, css_class='ui submit button large primary'+save_button_extra_css))


class CosmicAuthenticationForm(AuthenticationForm):
    def __init__(self, request=None, *args, **kwargs):
        super().__init__(request=None, *args, **kwargs)
        self.helper = CosmicFormHelper(save_button_value='Login', save_button_name='login', save_button_extra_css=' fluid ')


class CosmicSignupUserForm(forms.ModelForm):
    def clean_email(self):
        email = self.cleaned_data['email']
        if User.objects.filter(email=email).count() > 0:
            raise forms.ValidationError('This email is in use.')
        return email

    def clean_username(self):
        username = self.cleaned_data['username']
        if len(username) < 5:
            raise forms.ValidationError('Username must be 5 or more characters.')
        return username

    def clean_password(self):
        password = self.cleaned_data.get('password')
        self.instance.username = self.cleaned_data.get('username')
        password_validation.validate_password(password, self.instance)
        return password

    def __init__(self, *args, **kwargs):
        super(CosmicSignupUserForm, self).__init__(*args, **kwargs)
        self.fields['password'].widget = forms.PasswordInput()
        self.fields['email'].required = True
        self.helper = CosmicFormHelper(self, save_button_value='Create account', save_button_name='login', save_button_extra_css=' fluid ')

    class Meta:
        model = User
        fields = ('username', 'email', 'password')
        help_items = [format_html('<li>{}</li>', help_text) for help_text in password_validation.password_validators_help_texts()]
        help_text_html = '<ul class="help-block">%s</ul>' % ''.join(help_items)
        help_texts = {
            'password': help_text_html,
        }


class CosmicPasswordResetForm(PasswordResetForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.helper = CosmicFormHelper(self, save_button_value='Reset my password', save_button_name='reset_pw', save_button_extra_css=' fluid ')


class CosmicSetPasswordForm(SetPasswordForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.helper = CosmicFormHelper(self, save_button_value='Reset my password', save_button_name='reset_pw', save_button_extra_css=' fluid ')


class CosmicChangeEmailForm(forms.Form):
    email = forms.EmailField(label="New email")

    def __init__(self, *args, **kwargs):
        self.request = kwargs.pop('request', None)
        super(CosmicChangeEmailForm, self).__init__(*args, **kwargs)
        self.fields['email'].initial = self.request.user.email
        self.helper = CosmicFormHelper(self, save_button_value='Change email')

    def clean_email(self):
        email = self.cleaned_data.get("email")
        check_email_exists_qs = User.objects.filter(email=email)
        if email == self.request.user.email:
            raise forms.ValidationError("Email address entered is the same as your current email address.")
        if check_email_exists_qs.count() >= 1:
            raise forms.ValidationError("Email address is already in use.")
        return email


class CosmicPasswordChangeForm(PasswordChangeForm):
    def __init__(self, *args, **kwargs):
        super(CosmicPasswordChangeForm, self).__init__(*args, **kwargs)
        self.helper = CosmicFormHelper(self, save_button_value='Change password')




from django.contrib import admin
from django.contrib.auth.admin import UserAdmin
from django.utils.translation import ugettext_lazy as _

from sitetree.admin import TreeItemAdmin, TreeAdmin, override_tree_admin, override_item_admin

from cosmicdb.models import User, UserSystemNotification


class UserSystemNotificationInlineAdmin(admin.TabularInline):
    model = UserSystemNotification


class UserProfileAdmin(UserAdmin):
    inlines = [
        UserSystemNotificationInlineAdmin,
    ]


admin.site.register(User, UserProfileAdmin)


class CosmicDBTreeAdmin(TreeAdmin):
    pass


class CosmicDBTreeItemAdmin(TreeItemAdmin):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fieldsets = (
            (_('Basic settings'), {
                'fields': ('parent', 'title', 'url', 'is_right', 'is_button')
            }),
            (_('Access settings'), {
                'classes': ('collapse',),
                'fields': ('access_loggedin', 'access_guest', 'access_restricted', 'access_permissions', 'access_perm_type')
            }),
            (_('Display settings'), {
                'classes': ('collapse',),
                'fields': ('hidden', 'inmenu', 'inbreadcrumbs', 'insitetree')
            }),
            (_('Additional settings'), {
                'classes': ('collapse',),
                'fields': ('hint', 'description', 'alias', 'urlaspattern')
            }),
        )

override_tree_admin(CosmicDBTreeAdmin)
override_item_admin(CosmicDBTreeItemAdmin)



from django.conf import settings
from django import template
from django.urls import reverse
from django.utils.safestring import mark_safe

import importlib

register = template.Library()


@register.simple_tag
def get_site_title():
    return settings.COSMICDB_SITE_TITLE or "CosmicDB"



# Generated by Django 2.0.5 on 2018-05-20 05:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cosmicdb', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='cosmicdbtreeitem',
            name='is_button',
            field=models.BooleanField(default=False),
        ),
    ]



from django.db import models
from django.contrib.auth.models import AbstractUser
from django.utils.safestring import mark_safe

from bs4 import BeautifulSoup

from sitetree.models import TreeItemBase, TreeBase


class User(AbstractUser):

    def unread_notification_no(self):
        return self.usersystemnotification_set.filter(read=False).count()

    def unread_notifications(self):
        return self.usersystemnotification_set.filter(read=False).order_by('-created_at')[:3]

    def read_notifications(self):
        return self.usersystemnotification_set.filter(read=True).order_by('-created_at')[:3]

    def read_notification_no(self):
        return self.usersystemnotification_set.filter(read=True).count()


    created_at = models.DateTimeField(auto_now_add=True)
    updated_at = models.DateTimeField(auto_now=True)

    def __str__(self):
        return u'%s' % (self.username)


class UserSystemNotification(models.Model):
    user = models.ForeignKey('User', on_delete=models.PROTECT)
    notification = models.TextField()
    def short_notification(self):
        notification_no_html = BeautifulSoup(self.notification, "html.parser").get_text()
        return notification_no_html[:30]+'..'
    read = models.BooleanField(default=False)

    created_at = models.DateTimeField(auto_now_add=True)
    updated_at = models.DateTimeField(auto_now=True)

    def __str__(self):
        return u'%s - %s' % (self.user, self.short_notification())


class CosmicDBTree(TreeBase):
    pass


class CosmicDBTreeItem(TreeItemBase):
    is_right = models.BooleanField(default=False)
    is_button = models.BooleanField(default=False)
